@@ -503,12 +503,13 @@ async_jitter_queue_insert_after_unlocked (AsyncJitterQueue * queue,
 }
 
 static gpointer
-async_jitter_queue_pop_intern_unlocked (AsyncJitterQueue * queue)
+async_jitter_queue_pop_intern_unlocked (AsyncJitterQueue * queue,
+    gboolean ignore_flushing)
 {
   gpointer retval;
   GstBuffer *tail_buffer = NULL;
 
-  if (queue->pop_flushing)
+  if (queue->pop_flushing && !ignore_flushing)
     return NULL;
 
   /* if pops are remaining, do it now without blocking */
@@ -536,7 +537,7 @@ async_jitter_queue_pop_intern_unlocked (AsyncJitterQueue * queue)
           g_cond_wait(queue->cond, queue->mutex);
           queue->waiting_threads--;
           //g_debug ("done waiting");
-          if (queue->pop_flushing)
+          if (queue->pop_flushing && !ignore_flushing)
             return NULL;
         }
       }
@@ -551,7 +552,7 @@ async_jitter_queue_pop_intern_unlocked (AsyncJitterQueue * queue)
         g_cond_wait(queue->cond, queue->mutex);
         queue->waiting_threads--;
         //g_debug ("done waiting");
-        if (queue->pop_flushing)
+        if (queue->pop_flushing && !ignore_flushing)
           return NULL;
       }
     }
@@ -611,7 +612,7 @@ async_jitter_queue_pop (AsyncJitterQueue * queue)
   g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
   g_mutex_lock (queue->mutex);
-  retval = async_jitter_queue_pop_intern_unlocked (queue);
+  retval = async_jitter_queue_pop_intern_unlocked (queue, FALSE);
   g_mutex_unlock (queue->mutex);
 
   return retval;
@@ -633,7 +634,26 @@ async_jitter_queue_pop_unlocked (AsyncJitterQueue * queue)
   g_return_val_if_fail (queue, NULL);
   g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
 
-  return async_jitter_queue_pop_intern_unlocked (queue);
+  return async_jitter_queue_pop_intern_unlocked (queue, FALSE);
+}
+
+/**
+ * async_jitter_queue_pop_unlocked_forced:
+ * @queue: a #AsyncJitterQueue.
+ *
+ * Pops data from the @queue. This function blocks until data become
+ * available. This function must be called while holding the @queue's
+ * lock. It will return data even if the queue is flushing.
+ *
+ * Return value: data from the queue.
+ **/
+gpointer
+async_jitter_queue_pop_unlocked_forced (AsyncJitterQueue * queue)
+{
+  g_return_val_if_fail (queue, NULL);
+  g_return_val_if_fail (g_atomic_int_get (&queue->ref_count) > 0, NULL);
+
+  return async_jitter_queue_pop_intern_unlocked (queue, TRUE);
 }
 
 /**
