@@ -66,6 +66,11 @@ enum
 #define DEFAULT_SSRC             -1
 #define DEFAULT_CLOCK_RATE        0
 
+typedef struct {
+  gboolean have_base;
+  guint clock_base;
+} GstRTPMuxPadPrivate;
+
 static GstStaticPadTemplate src_factory = GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_SRC,
     GST_PAD_ALWAYS,
@@ -86,6 +91,7 @@ static void gst_rtp_mux_finalize (GObject * object);
 
 static GstPad *gst_rtp_mux_request_new_pad (GstElement * element,
     GstPadTemplate * templ, const gchar * name);
+static void gst_rtp_mux_release_pad (GstElement * element, GstPad *pad);
 static GstFlowReturn gst_rtp_mux_chain (GstPad * pad,
     GstBuffer * buffer);
 static gboolean gst_rtp_mux_setcaps (GstPad *pad, GstCaps *caps);
@@ -98,6 +104,8 @@ static void gst_rtp_mux_set_property (GObject * object, guint prop_id,
 static void gst_rtp_mux_get_property (GObject * object, guint prop_id,
     GValue * value, GParamSpec * pspec);
 
+static gboolean gst_rtp_mux_src_event (GstPad * pad, GstEvent * event);
+
 static GstElementClass *parent_class = NULL;
 
 GType
@@ -176,6 +184,7 @@ gst_rtp_mux_class_init (GstRTPMuxClass * klass)
           0, G_MAXUINT, DEFAULT_SSRC, G_PARAM_READWRITE));
 
   gstelement_class->request_new_pad = gst_rtp_mux_request_new_pad;
+  gstelement_class->release_pad = gst_rtp_mux_release_pad;
   gstelement_class->change_state = gst_rtp_mux_change_state;
 
   klass->chain_func = gst_rtp_mux_chain;
@@ -189,7 +198,7 @@ static gboolean gst_rtp_mux_src_event (GstPad * pad,
   GstPad *sinkpad;
   gboolean result = FALSE;
   gboolean done = FALSE;
-  
+
   rtp_mux = gst_pad_get_parent_element (pad);
   g_return_val_if_fail (rtp_mux != NULL, FALSE);
 
@@ -204,6 +213,7 @@ static gboolean gst_rtp_mux_src_event (GstPad * pad,
         break;
       case GST_ITERATOR_RESYNC:
         gst_iterator_resync (iter);
+        result = FALSE;
         break;
       case GST_ITERATOR_ERROR:
         GST_WARNING_OBJECT (rtp_mux, "Error iterating sinkpads");
@@ -212,7 +222,8 @@ static gboolean gst_rtp_mux_src_event (GstPad * pad,
         break;
     }
   }
-
+  gst_iterator_free (iter);
+  gst_object_unref (rtp_mux);
   gst_event_unref (event);
 
   return result;
@@ -228,7 +239,7 @@ gst_rtp_mux_init (GstRTPMux * rtp_mux)
           "src"), "src");
   gst_pad_set_event_function (rtp_mux->srcpad, gst_rtp_mux_src_event);
   gst_element_add_pad (GST_ELEMENT (rtp_mux), rtp_mux->srcpad);
-  
+
   rtp_mux->ssrc = DEFAULT_SSRC;
   rtp_mux->ts_offset = DEFAULT_TIMESTAMP_OFFSET;
   rtp_mux->seqnum_offset = DEFAULT_SEQNUM_OFFSET;
@@ -250,7 +261,7 @@ gst_rtp_mux_create_sinkpad (GstRTPMux * rtp_mux, GstPadTemplate * templ)
 {
   GstPad *newpad = NULL;
   GstPadTemplate * class_templ;
-  
+
   class_templ = gst_element_class_get_pad_template (
           GST_ELEMENT_GET_CLASS (rtp_mux), "sink_%d");
 
@@ -274,9 +285,10 @@ static void
 gst_rtp_mux_setup_sinkpad (GstRTPMux * rtp_mux, GstPad * sinkpad)
 {
   GstRTPMuxClass *klass;
+  GstRTPMuxPadPrivate *padpriv = g_slice_new0 (GstRTPMuxPadPrivate);
 
   klass = GST_RTP_MUX_GET_CLASS (rtp_mux);
-  
+
   /* setup some pad functions */
   gst_pad_set_setcaps_function (sinkpad, gst_rtp_mux_setcaps);
   if (klass->chain_func)
@@ -287,6 +299,8 @@ gst_rtp_mux_setup_sinkpad (GstRTPMux * rtp_mux, GstPad * sinkpad)
   /* This could break with gstreamer 0.10.9 */
   gst_pad_set_active (sinkpad, TRUE);
 
+  gst_pad_set_element_private (sinkpad, padpriv);
+
   /* dd the pad to the element */
   gst_element_add_pad (GST_ELEMENT (rtp_mux), sinkpad);
 }
@@ -317,44 +331,33 @@ gst_rtp_mux_request_new_pad (GstElement * element,
   return newpad;
 }
 
-static guint32
-gst_rtp_mux_get_buffer_ts_base (GstRTPMux * rtp_mux, GstBuffer * buffer)
+static void
+gst_rtp_mux_release_pad (GstElement * element, GstPad *pad)
 {
-  GstCaps *caps;
-  GstStructure *structure;
-  const GValue *value;
-  guint32 ts_base;
-   
-  caps = gst_buffer_get_caps (buffer);
-  g_return_val_if_fail (caps != NULL, 0);
+  GstRTPMuxPadPrivate *padpriv = gst_pad_get_element_private (pad);
 
-  structure = gst_caps_get_structure (caps, 0);
-  g_return_val_if_fail (structure != NULL, 0);
+  if (padpriv)
+    g_slice_free (GstRTPMuxPadPrivate, padpriv);
+  gst_pad_set_element_private (pad, NULL);
 
-  value = gst_structure_get_value (structure, "clock-base");
-
-  if (value) 
-    ts_base = g_value_get_uint (value);
-  else
-    ts_base = 0;
-  
-  gst_caps_unref (caps);
-  
-  GST_DEBUG_OBJECT (rtp_mux, "sink's ts-base: %u", ts_base);
-  return ts_base;
+  gst_element_remove_pad (element, pad);
 }
 
 /* Put our own clock-base on the buffer */
 static void
-gst_rtp_mux_readjust_rtp_timestamp (GstRTPMux * rtp_mux, GstBuffer * buffer)
+gst_rtp_mux_readjust_rtp_timestamp (GstRTPMux * rtp_mux, GstPad * pad,
+    GstBuffer * buffer)
 {
   guint32 ts;
-  guint32 sink_ts_base;
+  guint32 sink_ts_base = 0;
+  GstRTPMuxPadPrivate *padpriv = gst_pad_get_element_private (pad);
+
+  if (padpriv->have_base)
+    sink_ts_base = padpriv->clock_base;
 
-  sink_ts_base = gst_rtp_mux_get_buffer_ts_base (rtp_mux, buffer);
   ts = gst_rtp_buffer_get_timestamp (buffer) - sink_ts_base + rtp_mux->ts_base;
-  GST_DEBUG_OBJECT (rtp_mux, "Re-adjusting RTP ts %u to %u",
-          gst_rtp_buffer_get_timestamp (buffer), ts);
+  GST_LOG_OBJECT (rtp_mux, "Re-adjusting RTP ts %u to %u",
+      gst_rtp_buffer_get_timestamp (buffer), ts);
   gst_rtp_buffer_set_timestamp (buffer, ts);
 }
 
@@ -362,22 +365,27 @@ static GstFlowReturn
 gst_rtp_mux_chain (GstPad * pad, GstBuffer * buffer)
 {
   GstRTPMux *rtp_mux;
+  GstStructure * structure;
   GstFlowReturn ret;
-  
+
   rtp_mux = GST_RTP_MUX (gst_pad_get_parent (pad));
 
   buffer = gst_buffer_make_writable(buffer);
 
   rtp_mux->seqnum++;
-  GST_LOG_OBJECT (rtp_mux, "setting RTP seqnum %d", rtp_mux->seqnum);
   gst_rtp_buffer_set_seq (buffer, rtp_mux->seqnum);
+  GST_BUFFER_CAPS (buffer) = gst_caps_make_writable(GST_BUFFER_CAPS (buffer));
+  structure = gst_caps_get_structure (GST_BUFFER_CAPS (buffer), 0U);
+  gst_structure_set (structure, "seqnum-base", G_TYPE_UINT, rtp_mux->seqnum_base, NULL);
   gst_rtp_buffer_set_ssrc (buffer, rtp_mux->current_ssrc);
-  gst_rtp_mux_readjust_rtp_timestamp (rtp_mux, buffer);
-  GST_DEBUG_OBJECT (rtp_mux, "Pushing packet size %d, seq=%d, ts=%u",
-          GST_BUFFER_SIZE (buffer), rtp_mux->seqnum - 1);
+  gst_rtp_mux_readjust_rtp_timestamp (rtp_mux, pad, buffer);
+  GST_LOG_OBJECT (rtp_mux, "Pushing packet size %d, seq=%d, ts=%u",
+      GST_BUFFER_SIZE (buffer), rtp_mux->seqnum);
+
+  gst_buffer_set_caps (buffer, GST_PAD_CAPS (rtp_mux->srcpad));
 
   ret = gst_pad_push (rtp_mux->srcpad, buffer);
-    
+
   gst_object_unref (rtp_mux);
   return ret;
 }
@@ -408,6 +416,7 @@ gst_rtp_mux_setcaps (GstPad *pad, GstCaps *caps)
   GstStructure *structure;
   gboolean ret = TRUE;
   gint clock_rate;
+  GstRTPMuxPadPrivate *padpriv = gst_pad_get_element_private (pad);
 
   rtp_mux = GST_RTP_MUX (gst_pad_get_parent (pad));
 
@@ -416,12 +425,26 @@ gst_rtp_mux_setcaps (GstPad *pad, GstCaps *caps)
     ret = gst_rtp_mux_set_clock_rate (rtp_mux, clock_rate);
   }
 
-  if (ret) {
-    GST_DEBUG_OBJECT (rtp_mux,
-            "seting caps %" GST_PTR_FORMAT " on src pad..", caps);
-    ret = gst_pad_set_caps (rtp_mux->srcpad, caps);
+  if (!ret)
+    goto out;
+
+  if (gst_structure_get_uint (structure, "clock-base", &padpriv->clock_base)) {
+    padpriv->have_base = TRUE;
   }
 
+  caps = gst_caps_copy (caps);
+
+  gst_caps_set_simple (caps,
+      "clock-base", G_TYPE_UINT, rtp_mux->ts_base,
+      "seqnum-base", G_TYPE_UINT, rtp_mux->seqnum_base,
+      NULL);
+
+  GST_DEBUG_OBJECT (rtp_mux,
+      "setting caps %" GST_PTR_FORMAT " on src pad..", caps);
+  ret = gst_pad_set_caps (rtp_mux->srcpad, caps);
+  gst_caps_unref (caps);
+
+ out:
   gst_object_unref (rtp_mux);
 
   return ret;
@@ -484,7 +507,7 @@ gst_rtp_mux_set_property (GObject * object,
   }
 }
 
-static void 
+static void
 gst_rtp_mux_ready_to_paused (GstRTPMux * rtp_mux)
 {
   if (rtp_mux->ssrc == -1)
@@ -496,8 +519,8 @@ gst_rtp_mux_ready_to_paused (GstRTPMux * rtp_mux)
     rtp_mux->seqnum_base = g_random_int_range (0, G_MAXUINT16);
   else
     rtp_mux->seqnum_base = rtp_mux->seqnum_offset;
-    rtp_mux->seqnum = rtp_mux->seqnum_base;
-      
+  rtp_mux->seqnum = rtp_mux->seqnum_base;
+
   if (rtp_mux->ts_offset == -1)
     rtp_mux->ts_base = g_random_int ();
   else
