@@ -170,9 +170,9 @@ fs_selector_class_init (FsSelectorClass *klass)
 
   parent_class = g_type_class_peek_parent (klass);
 
-  internal_srcpad_quark = g_quark_from_string ("internal_srcpad");
-  internal_sinkpad_quark = g_quark_from_string ("internal_sinkpad");
-  parent_quark = g_quark_from_string ("parent");
+  internal_srcpad_quark = g_quark_from_static_string ("internal_srcpad");
+  internal_sinkpad_quark = g_quark_from_static_string ("internal_sinkpad");
+  parent_quark = g_quark_from_static_string ("parent");
 }
 
 static void
@@ -766,6 +766,7 @@ get_out:
   if (selector->current_subelement) {
     return TRUE;
   } else {
+    GST_WARNING_OBJECT (selector, "Could not find a matching element for caps");
     return FALSE;
   }
 }
@@ -886,6 +887,9 @@ fs_selector_sink_chain (GstPad *pad, GstBuffer *buffer)
   if (internal_srcpad) {
     ret = gst_pad_push (internal_srcpad, buffer);
     gst_object_unref (internal_srcpad);
+  } else {
+    GST_ERROR_OBJECT (selector, "Got buffer without an negotiated element,"
+                      " returning not-negotiated");
   }
 
   gst_object_unref (selector);
@@ -905,7 +909,7 @@ fs_selector_sink_event (GstPad *pad, GstEvent *event)
     ret = gst_pad_push_event (internal_srcpad, event);
     gst_object_unref (internal_srcpad);
   } else {
-    GST_WARNING_OBJECT (selector, "Got event while not element was selected,"
+    GST_WARNING_OBJECT (selector, "Got event while no element was selected,"
         "letting through");
     ret = gst_pad_push_event (selector->srcpad, event);
   }
